<%inherit file="base.html"/> <%block name="title">Bank Account List
<%block name="javascript_init"> $(function(){ $('.login_dialog').dialog({ autoOpen: false, modal: true, title: "Add bank account", width: 400, height: 275, buttons: [ { text: 'Cancel', click: function() { $(this).find("input[name='username']").val('') $(this).find("input[name='password']").val('') $(this).find("input[name='id']").val('') $(this).dialog('close') } }, { text: 'Save', click: function() { u = $(this).find("input[name='username']").val() p = $(this).find("input[name='password']").val() i = $(this).find("input[name='id']").val() dialog = $(this) data = { id: i, username: u, password: p } $.ajax({ url: '/rest/add_bank', type: 'POST', dataType: 'json', data: data }).success(function(d) { $('.error_box').hide() $('.login_dialog').dialog('close') document.location = '/' }).error(function(d) { j = $.parseJSON(d.responseText) console.log(j) message = j['message'] box = $('.error_box') box.find('.message').text(message) box.show() }); } } ] }); $('.results button').button({ icons: {primary:'ui-icon-plusthick'} }).click(function() { id = $(this).find('.guid').text() description = $(this).find('.description').text() dialog = $('.login_dialog') $('#guid').val(id) dialog.dialog({ title: description }) dialog.dialog('open') dialog.find("input[name='username']").focus() }); }); <%namespace name="search_box" file="search_box.html"/>
% for i in institutions:
% endfor
% if not institutions: % if q: ${search_box.form(error='Could not find anything with "%s"' % q,query=q)} % else: ${search_box.form()} % endif % endif

Some wacky error happened

Username (or member number) Password (or PIN)